polyc-controller 2026.10.0

Conversation CRD + kube reconciler for the polychrome control plane.
docs.rs failed to build polyc-controller-2026.10.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.